aboutsummaryrefslogtreecommitdiffstats
path: root/Game/Code/Classes/UDataBase.pas
diff options
context:
space:
mode:
authortobigun <tobigun@b956fd51-792f-4845-bead-9b4dfca2ff2c>2008-05-02 16:52:53 +0000
committertobigun <tobigun@b956fd51-792f-4845-bead-9b4dfca2ff2c>2008-05-02 16:52:53 +0000
commit43806a5ca483e8767066d5a7b1e02557056e40bd (patch)
treeea975f18815aec37f03f8cba1e38f68d64c0def3 /Game/Code/Classes/UDataBase.pas
parentfffe085266382cfcaeed4b600f4d6bb104bfa38d (diff)
downloadusdx-43806a5ca483e8767066d5a7b1e02557056e40bd.tar.gz
usdx-43806a5ca483e8767066d5a7b1e02557056e40bd.tar.xz
usdx-43806a5ca483e8767066d5a7b1e02557056e40bd.zip
TCoreModule overloads the Free destructor "destructor Free" with a self defined "procedure Free". At least Free should not be defined explicitly because there already is a default Free() implementation that checks if the reference is nil and if not, calls Destroy. Making the destructor a procedure does not look correct too.
git-svn-id: svn://svn.code.sf.net/p/ultrastardx/svn/trunk@1054 b956fd51-792f-4845-bead-9b4dfca2ff2c
Diffstat (limited to '')
-rw-r--r--Game/Code/Classes/UDataBase.pas6
1 files changed, 3 insertions, 3 deletions
diff --git a/Game/Code/Classes/UDataBase.pas b/Game/Code/Classes/UDataBase.pas
index 3954f92e..f7f39634 100644
--- a/Game/Code/Classes/UDataBase.pas
+++ b/Game/Code/Classes/UDataBase.pas
@@ -46,7 +46,7 @@ type
property Filename: String read sFilename;
- Destructor Free;
+ Destructor Destroy; override;
Procedure Init(const Filename: string);
procedure ReadScore(Song: TSong);
@@ -114,9 +114,9 @@ begin
end;
//--------------------
//Free - Frees Database
//--------------------
-Destructor TDataBaseSystem.Free;
+Destructor TDataBaseSystem.Destroy;
begin
debugWriteln( 'TDataBaseSystem.Free' );
@@ -114,9 +114,9 @@ begin
end;
//--------------------
-//Free - Frees Database
+//Destroy - Frees Database
//--------------------